@@ -99,6 +99,8 @@ MainWindow::MainWindow(QWidget *parent) :
   changeFontSize(30);
   isStartStopModeActive = false;
   useDeltaTime = false;
+  timeOutput = false;
+  actionEnable_full_date->setEnabled(false);
   resetProgram();
 #ifdef Q_WS_MAEMO_5
   path = "/home/user/MyDocs/.push-it.rc";
@@ -763,7 +765,11 @@ void MainWindow::mainButtonRefreshTextOnly()
   QStringList lines;
   QString header = getHeaderLine();
 
-  if(1 == hitCount)
+  if(0 == hitCount)
+  {
+    return; //nothing to do
+  }
+  else if(1 == hitCount)
   {
     string = header;
   }
@@ -1004,14 +1010,7 @@ int MainWindow::setStartPauseFlag(int n)
 int MainWindow::setShowTimeDateFlag(int n)
 {
   actionEnable_time_and_date->setChecked(bool(n));
-  if(n)
-  {
-    actionEnable_full_date->setEnabled(true);
-  }
-  else
-  {
-    actionEnable_full_date->setEnabled(false);
-  }
+  actionEnable_full_date->setEnabled(bool(n));
   return (timeOutput = bool(n));
 }
 int MainWindow::setShowFullDateFlag(int n)
