@@ -17,14 +17,24 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <stdio.h>
+
 #include <QMainWindow>
 #include <QTimer>
 #include <QPushButton>
 #include <QAction>
 #include <QMenuBar>
+
 #include "fullscreenexitbutton.h"
 #include "timekeeper.h"
-#include <stdio.h>
+#include "releaseinformation.hpp"
+
+//QTM_USE_NAMESPACE
+
+/**
+Structs
+*/
+
 
 class MainWindow : public QMainWindow
 {
@@ -52,25 +62,52 @@ public:
     void changeNumberOfLines(int number = 0);
     void changeFontSize(int size = 0);
     void toggleStartStopMode();
+    void toggleUseDeltaTime();
+#ifdef Q_WS_MAEMO_5
+    void toggleDisableScreensaver();
+#endif
 
 private:
+    struct StringFunctionMap
+    {
+      QString string;
+      int (MainWindow::*getFunction)();
+      int (MainWindow::*setFunction)(int);
+    };
+
     int resetCounters();
     int resetUi();
     int updateTime();
     int toggleTimer();
     int toggleActionPause();
     int updateUiText();
+    int loadFile();
+    int saveFile();
 
     void setupUi();
     void retranslateUi();
 
+    int getNumberOfLines();
+    int getFontSize();
+    int getDeltaModeFlag();
+    int getShowTimeDateFlag();
+    int getShowFullDateFlag();
+    int getStartPauseFlag();
+
+    int setNumberOfLines(int);
+    int setFontSize(int);
+    int setDeltaModeFlag(int);
+    int setShowTimeDateFlag(int);
+    int setShowFullDateFlag(int);
+    int setStartPauseFlag(int);
+
+    StringFunctionMap* getSfm();
+
     QAction *actionReset;
-    QAction *actionSimulated_click;
     QAction *actionPause;
     QAction *actionStartStopMode;
 
     QAction *actionShow_full_list;
-    QAction *actionSave_full_list;
     QAction *actionEnable_full_date;
     QAction *actionEnable_time_and_date;
 
@@ -78,6 +115,10 @@ private:
     QAction *actionResetFs;
     QAction *actionChangeNumberOfLines;
     QAction *actionChangeFontSize;
+    QAction *actionUseDeltaTime;
+#ifdef Q_WS_MAEMO_5
+    QAction *actionDisableScreensaver;
+#endif
 
     QAction *actionAbout;
 
@@ -93,16 +134,25 @@ private:
     QString generateHistoryString();
     QString getHeaderLine();
 
-    class timeKeeper overallTime;
+    class TimeKeeper overallTime;
 
     char mainButtonStartText[BUFSIZ];
     QTimer *timer;
     QString completeString;
     int hitCount;
     int timerRefreshTimeMs;
+
+    //ui customization
+    QString path;
     bool timeOutput;
     int maximumNumberOfLines;
+    int fontSize;
     bool isStartStopModeActive;
+    bool useDeltaTime;
+
+    StringFunctionMap *sfm;
+
+    ReleaseInformation releaseInfo;
 };
 
 #endif // MAINWINDOW_H
